| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Language.QBE.Simulator.Concolic.State
Synopsis
- data Env = Env {}
- mkEnv :: Program -> Address -> Size -> Maybe Int -> IO Env
- run :: Env -> SimState a -> IO (ExecTrace, Store)
- runPath :: SimState a -> SimState (ExecTrace, Store)
- makeConcolic :: String -> ExtType -> SimState (Concolic RegVal)
- data ErrorState = ErrorState {}
- data ErrorPath = ErrorPath {}
- newtype SimState a = SimState {
- unSimState :: StateT Env IO a
Documentation
Constructors
| Env | |
data ErrorState Source #
State of the concolic executor with which an error was triggered in the application code, which can be reproduced using this state.
Constructors
| ErrorState | |
Exception thrown upon encountered an ErrorState.
Constructors
| ErrorPath | |
Fields | |
Instances
| Exception ErrorPath Source # | |
Defined in Language.QBE.Simulator.Concolic.State Methods toException :: ErrorPath -> SomeException # fromException :: SomeException -> Maybe ErrorPath # displayException :: ErrorPath -> String # | |
| Show ErrorPath Source # | |
Constructors
| SimState | |
Fields
| |